%-----------------------------
% initialize the output arrays
%-----------------------------

% auxiliary variables
  % Solubility of CO2 [mol/kg/Pa]
    output_k0_co2          = zeros(1   ,max_output_index)/0.0;
    output_scalar_k0_co2          = 0.0;
  % Acid dissociation constant CO2 + 2 H2O <-> HCO3- + H3O+ [mol/kg]
    output_k1_co2          = zeros(1   ,max_output_index)/0.0;
    output_scalar_k1_co2          = 0.0;
  % Acid dissociation constant HCO3- + H2O <-> [CO3 2-] + H3O+ [mol/kg]
    output_k2_co2          = zeros(1   ,max_output_index)/0.0;
    output_scalar_k2_co2          = 0.0;
  % boron alkalinity [mol/kg]
    output_alk_boron       = zeros(1   ,max_output_index)/0.0;
    output_scalar_alk_boron       = 0.0;
  % hydrogen sulfide alkalinity [mol/kg]
    output_alk_h2s         = zeros(1   ,max_output_index)/0.0;
    output_scalar_alk_h2s         = 0.0;
  % water alkalinity [mol/kg]
    output_alk_water       = zeros(1   ,max_output_index)/0.0;
    output_scalar_alk_water       = 0.0;
  % phosphate alkalinity [mol/kg]
    output_alk_po4         = zeros(1   ,max_output_index)/0.0;
    output_scalar_alk_po4         = 0.0;
  % carbonate alkalinity [mol/kg]
    output_alk_co2         = zeros(1   ,max_output_index)/0.0;
    output_scalar_alk_co2         = 0.0;
  % error in total alkalinity calculation at the assumed pH [mol/kg]
    output_alk_residual    = zeros(1   ,max_output_index)/0.0;
    output_scalar_alk_residual    = 0.0;
  % derivative of phosphate alkalinity with respect to h3o [1]
    output_dalkp_dh3o      = zeros(1   ,max_output_index)/0.0;
    output_scalar_dalkp_dh3o      = 0.0;
  % derivative of carbonate alkalinity with respect to h3o [1]
    output_dalkc_dh3o      = zeros(1   ,max_output_index)/0.0;
    output_scalar_dalkc_dh3o      = 0.0;
  % derivative of residual_alk with respect to pH [mol/kg]
    output_dalkresidual_dpH = zeros(1   ,max_output_index)/0.0;
    output_scalar_dalkresidual_dpH = 0.0;
  % newly determined pH value [1]
    output_ph              = zeros(1   ,max_output_index)/0.0;
    output_scalar_ph              = 0.0;
  % h3o ion concentration [mol/kg]
    output_h3o             = zeros(1   ,max_output_index)/0.0;
    output_scalar_h3o             = 0.0;
  % co2 partial pressure [Pa]
    output_pco2            = zeros(1   ,max_output_index)/0.0;
    output_scalar_pco2            = 0.0;
  % CO2 concentration in the surface layer [mol/kg]
    output_co2             = zeros(1   ,max_output_index)/0.0;
    output_scalar_co2             = 0.0;

% tracers
  % dissolved molecular nitrogen :
    output_t_n2 = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_n2 = zeros(1,kmax);
  % dissolved oxygen :
    output_t_o2 = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_o2 = zeros(1,kmax);
  % dissolved inorganic carbon, treated as carbon dioxide :
    output_t_dic = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_dic = zeros(1,kmax);
  % ammonium :
    output_t_nh4 = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_nh4 = zeros(1,kmax);
  % nitrate :
    output_t_no3 = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_no3 = zeros(1,kmax);
  % phosphate :
    output_t_po4 = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_po4 = zeros(1,kmax);
  % small-cell phytoplankton :
    output_t_spp = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_spp = zeros(1,kmax);
  % zooplankton :
    output_t_zoo = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_zoo = zeros(1,kmax);
  % hydrogen sulfide :
    output_t_h2s = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_h2s = zeros(1,kmax);
  % sulfur :
    output_t_sul = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_sul = zeros(1,kmax);
  % total alkalinity :
    output_t_alk = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_alk = zeros(1,kmax);
  % suspended iron phosphate :
    output_t_ipw = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_ipw = zeros(1,kmax);
  % large-cell phytoplankton :
    output_t_lpp = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_lpp = zeros(1,kmax);
  % diazotroph cyanobacteria :
    output_t_cya = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_cya = zeros(1,kmax);
  % detritus :
    output_t_det = zeros(kmax,max_output_index)/0.0; 
    output_vector_t_det = zeros(1,kmax);
  % sediment detritus :
    output_t_sed = zeros(1   ,max_output_index)/0.0;
    output_scalar_t_sed = 0.0;
  % iron phosphate in sediment :
    output_t_ips = zeros(1   ,max_output_index)/0.0;
    output_scalar_t_ips = 0.0;

% processes
  % downward co2 flux through the surface
    output_p_co2_stf_down  = zeros(1   ,max_output_index)/0.0;
    output_scalar_p_co2_stf_down  = 0.0;
  % upward co2 flux through the surface
    output_p_co2_stf_up    = zeros(1   ,max_output_index)/0.0;
    output_scalar_p_co2_stf_up    = 0.0;
